
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsT.\x00\x00PYARMOR\x00\x00\x03\x07\x00B\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x14.\x00\x00\x00\x00\x00\x00\x9dH\xb4\xb4\x81\x8c\xdf\rP\xe2>\xd9\xbf\x9e\xb9.\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf2\x8f\x02\x1eE\xf1'
        b'\xfa,A\xaf\x82^`9\x84\xb1t\xbfe\xad|\xce\x85\xa6p\xfa\x00@\x8a\x9e\xcc\xed\xf5\x8f\xc6\x1fU\x9e\x13\x1b\x02\x88\xce\x0f\xf8\xcb\x82C;`\x92\xc4\xfc\xaf\xaf5\x97D\xfc\xf2\xde\xb6~\xbc\xc2\xe9\x1d,\xff\x00'
        b'"\xc5\x1eW\xa3`#|4\xa6\x06\xa8\xad\xbe(\t\x82\x87O\xe1\x19\xa4b\x82\x90?\xad\x7f\xfe\xf4\xe4S\xdc\xa2MX\x11\xbfx\x98\xdd\xf7\x0fLx\x8c"\xae\x00\xf5\xaen\x89\xe0\x0c\x92\xd0BD\x14\xd8-|L'
        b'\x89\xa2\xb5\xf9S\xc6\xb7\xb4D\xc4Q\xb4Plj\x0b\xce \xabwm\xad\xfb\x92\xe5\xf1)\xf6I\xe4N\xa4\xef\xd8\x91YE\x17\x82t\xfd\xfdm\xa8\xd7q2\x1f\xf6\xfe1\x18\x95\xae\x19\xd0\x0f_\x99\x98\x8d\xa4\xe1\xbf'
        b'V\x88]\xb9\xc4\xb7\x1f\x91;\xb8\x88\x13\x0c\x82\xb8\x8f\x0clU\xca#\x9d\xea\x89\x9aT\xab\x8b\xf1\xd6\x0f\x89UB\xd3Tq\xb7\xc5\x91\xe0*#y\xe5\x157\x9c\xa8\x99\xe5Y\xe6\xceN\xc3\xb8\xc0\xe5\x80?\xb4}`'
        b"f*\xf8\xb7wyT\xfa\xe0\xe2\xc5\x9fn\xa7\xe9\r\x11\x80va\x12{x\xed-\x0c\x88<#\x08\xce\xf0\xed\xc2\x04?\xf9e@g\xb84\x99g\x17\xb01\xd7\xbe\x12#\x19'0\x18Z@m\xd4\xbc\t\xa4\xc8\xae"
        b'eg\x16 \xe7\xb3\x86\x84\xf9<\xa3\xdb\xfbJ\xd3.\xf9\xb7,c\xfcm\xa4fD\xd8\x9d\x81\xbbm\x0ca\x1d\x15L\xd3+Y\x17)n`E<\r\xb8s\x84w\xe1\xd4\xb3\x08\xab\n\xfd\xf8x\xc6\xfb`n\x04P'
        b'\xa7\xa1\xb7\x8f*\xdb\xf2\x81\xc2\xa7\xc0\x8d\x8f\x94\xbc\t\xe0\xb8\xa1\x17[N\xf4\x80\xfa\x01\x8b\xae\xdb\x90r\xddX\xc5\x0fw\xf7\x8b\xba\xeb\x9d\x7f\xc6\xcc$j,\xb4\x92c\x9f\\\xce\x1e\xb1\x8f$*\x96_){\xcc|'
        b'\xf0\xf8\xdb_\x98\xf9\xa8\xec\x80\xc4sC:\xbe\xf5k\xa3\xe4\xd8/D\xfa\xf0e\x7f\x0f!\xed~\xf9Wj\xd4_U\xdc\xe8\xaa\x1c\x03\x1cw\x9b\xe3\x9a\x04\xb4\x1e\x1d\x97D\xae\x1f\x12\xf7x\x02\x9ad\x80/Eh\xae'
        b"\xc70(\xb4`\n+\xbfj\xed\xe5\xc0\n\xe4_\xe7d\xa9\xb5\xa1\xff\xea\r\\z\r\x8d\x0f\x82Y+Z\xaf\xb7?\xfb'4Q\x8e\xaeZL\xbe\xe8NX\x94(\x017Jb\x18^\xd0\xfb\x80\xd7\xc9;\x0e\xe6\xc5"
        b'\x96+\x04N{\x81QW\xe4nK\xd7+\x14\x02\xd5\xb2h\x94^\x97u\xae\xbd\xe8\xc56\xc1\xb9\xce\x8e\xa3$xv\xb8\x7f&\x8b\x13{\xaa\x1f\xd6J\xd8\xb7\xf1L\x83\x94\xc0+P_J\x18L\xc1\xfdC@\x05\xc8'
        b'D\xed\x8b\xbb\x94\xae\x96\xfdN\xf3\xe6pwtv\xec\xfd9x\x15\x97\x9b\x12wu\'\x14\xfb!\xe1z\xa8\xd5\xce\xa4bp\x12+\x11\xa5c\x95\x7f\x12\xc0\x07\xd7-""\xd0\xfdf,O\xf8fY\x11k\x97\xf3]'
        b'\xb6D<\xe1+e\xee\x97\xf1Dz\xf0-\x11a\x96\xfb\x05\xe6%\x085\xc8\xd9\x1a\xc4\x00f\x8b9\xee\xd8\x08{U\xfd\x84\xad\xfb\xa9[\x1e\x9f\xb2\xeb\xa9fb\xc1\xa0\xcdX\xcaN%\xf8\x08q\x11\xa2\xce\x7f\xf8\xdf'
        b'>\xfaC\xfb\x1c{\xa3\xf9\x08\xbc\xb0$\xc0\xeci\x85\x06~\xf4\xfd\xa4\xfd\xea\xc8A\x1b\xa7\xc4\xd0\xd1\xe0\xf8)\xb9%\xd9\xf2k\xb0\x9f\x14\xb2\xb3V\x05\x07\\]\x04\x14\x1b1\xe7\x0bV\xb2s\xf0\x82\x8a91\xf6e'
        b'\xbe\x0e\xb4\x03\xef\xd8Or\xed.\x9cfK\x1f2\xe8\x0e\x85\x12\x19\xd7/\x85k\xac;\x85\xa3\xb8\xecD\x05U\x95aT\x94j~\xbe\t\xf4c\xd8k\x1e\x1cw\x01r\xecG\x0eRfo\xa2\x0e\xd1\xec\xc6L\x11X'
        b'_\x18N\x16\x86\xc2\x08K<\x84\xe1N\x8b\x1a\xd9q\x03q\xf0\x9d\x04\x84\xc8\xf4;\x1dwX\xba\xec\x05\xf6\xbe\x03\xb7\xf5\xa8;K\xef:\xf3\x1d\xb5\xad\xf5\x13k\xdb\xbfW\xc9\x90<\xaf\x00\xbd\x0e\xab\x0e38\xc5\xf3'
        b'l\xd9s\xac^\xb9\x94\xa7\x1a\xb9:\xac\xbb{\xac\xc5\xcelW\xb1<\xbbX\x13\xff7Bh\x9c\xefR\x8b\xb2\x0f\x92\x99\x9a\n\xf4\xd9oaH>\xf8(\x93\x9cT\xb6\xda\xe4\x06\x9ei\x8b\x9fB\x8f\xb1\x8c\xef\xa6\x08'
        b'\x93\xf5 \xb3E\x0fTg\x9c\xdeV\xab\x18:\x84\x15\x03kI\x9b6\xa0\xab>,/\xf4\xdbC6!\x87\xa29\xb4|AKP\xf40\x82G\xd31\xad\x82\xbel\xcd79K{j\xd7(\xc3\x13\x861VRL'
        b'q\xb3\x17\xf4\xb1\xb7i\xacSx/\xd4\x81}\xb8\x94(Qb\xc99\xce\x9b\xf7\xde\x87\xf8p\x0e*KN#-%\x10\xa2\xf7\xffH~\x01c\x9f\x85.\xca\xee\x1frC\x15\xd2\x10\x9e\x97vR\r\x1d\x16\xc38\\'
        b'\xe0\x05\xac@H\xe7\x1d\xc3\xd2\x9eM\xa5\x9b\x89-4\xc1D\x8d?v\x1e\x17\xb2\xa4\xcb\x13i8`7\xd6\xaed\xeb\x11x\xc2\xd10\xaa)\xcc\xb0w\xffW\x9e\xdb/\xb3\x05\xbb\xf7R\x8bfH\xca\xac}\xe6\xd7y'
        b'\xa4KI\xbeB\xd9A\xd3\xc2j\x02`\xbbt\x16_\xfe\xc0p\xc7%@\xd9Z^{\xbf\x15B~\x89l\x99k\xba\xec;\xbb\xe2\xe1\xcf\x802\xad\xd83f9\x08w\xba\xc7L\xfc\xb2\x0b\xe0\\\xa7\x8cX\xadQ\xf0'
        b'\xa5^\x82]O\t\xd4\x9d\xea-\xd8\xc7\x84\x89\x8a\xcd\xcd\xecz"\x8f\x9577\xc6Kb\xf2 ,Nl\tFM\x85{\x9a[\x92\xbbS\x94\x97\x14\x0eH\xa8\xbf`\x7f\x82\x15B\xe1\xd4\x0bJ#\x84I\x83\x18\x14'
        b'=\x7f$\xada\xd3w\xc3\x02\x9b_/\xb5\x98U|U]}\x15\xc1@\xcc\xd3_\xfd\xe3w!\xd24\x8bioa*l\x96\xd8Q\xeb\xfb\x87T\xee\t:b\xc0\xf5\x8e\x10/I\x17\xec\xf8*\xd7\x17B2\x114'
        b"1\x19]\x012J\xf3\x94~\x074\xe1Z]\xa8\xa2L]\x8a\x8ab<+,\x8ereG_\xbb\xad\r\xd9\x91S\xb8^g='Hg\xcbc\xb3\x81\xf4V8\r\xcc\xb9\x1de\xef\xc7)N\x001\xb8\xc6&\xf1"
        b'OnuMZ\x1f]UG\x0c\xa9L\xd3H\xe6[\xc5\x03\xb8\xaf\x82\x02;\xf4q\xee0\xba\xaa\xbb#!`\xfe#`\xa1\xe4\xb1\x15\xf4\xe2i\xaa\x7fz,\xd5\x1f%b\x1b\x8a\x1c\x8c\xb4\xd6\xe2R\xbfFS\xb6\x13'
        b'zy\x95TUu\x90T`\x9c\xbf\xdb_\xe0\xdf\xbc\xf9-\xbf\x9b\x05J\xa5\x7f\x04\xab\x1f\xd5\x8e\xbc\x01i\x1f\xe5\xdbe\xc6\x9c\xf8\x13\xf2\xa8\xd2\xb7\xc9j\xff\xd7\x7f\xbfc\x08\xf7b\xf0\xcc\x93\xe4\xd5gE\x8f\xa7f'
        b'\xb2y4\x1f\xf9\x16\x03\xd7x]\xe2\x14\xf3\xba\x0f\x8c\x18\x04\xdb\x19a>\x0c\xad\xa4\x0c\x02hSM\x10*\xc1\x80\x1a\xa1\xf7[\xdd\xe6k\x94\xf6\xe3\xdc\x13P\xcd.\xf9\xac\x9ek\x96^\x02!=\x07g\x01x1\xb8'
        b'p\xa0\x1bdN2\x02f\xe9\x19^\xed\xb2/\xdd@.|\xea\xab\x12\xf4\xbd\x89\xecB\x8fJ\xa3\x12C\xb8\x9a\xe5\xce\xec\x938KO\x87\xb7j\xb9Kw/\x03\x19\xd2\x91\x9f\xdd\x0b\x92\x10\xbb\x14O;\xba\xdd\x94\xfb'
        b'qO\xe0\x17v \x1c\x9e<\xdcq[ke\xe9\x14}\x91\xadG\xc88\xa0\x91\xbe\xe6\xb7v\xadN\x0b\xfd\xd3\x19\xed\x13\xbe\xa6bY\x97\x167i]+\xd8\x96\x06.\x82\x04B\xec\xe5=\x99n\xaa\x80\x9c\xc3\x84\xaf'
        b'\xd7\x18z\xf4\x08\x18\x12R\xf4.;\xb7\x04\x98&@\xcd\xa4 \xf3\x0cjc&\xc3nr\xb98\x85\x11\x1dqT\xd2\xec\x0f\x05\x1b\xa1\xfdpn\xa4\x1e9\x80\x7f\x87@\xc7ze\x06\xfc\tP\xab\xc8\xc2`\x0c\x91\x88'
        b'\xaa\x81f\x0e\xe6\x1f\xd81\x89\xa1\x11r\xbc\xec\x0fp\xbe\x1a\x9e\xa0\x08tGT\xf4)D\x1c\xe9\x07\x13V\x05\x905\x8bu\x0ft\x08b\xd83\xdfH\xc3u\xdehl]PR n:\x87gn\xd4\x81b M'
        b'6\x8c\xa5\xd9\xc1nOy\x8b\x8e\xebOT\xb5\x02\x8e^\xccB\r\x06\xa3\xd9\x91\xad-!\xdd5\xbd\xce\xeb\x89\xc2\xf4\x89\x9f\xcf\xeb\x1a\xc7%\x00\xe5\x94\xbdZ\x9d\x89e\x085\x8c[\x85|W\x1fM)\xf3\xf3\xbe\xba'
        b'W\x96"\xed\xcc\xb3;\x82b\xe8\xb0\xff\xcc\x08\xb1\xf8z\xe8x\xcdg\xfbZ\xe6\x0f\xfeK\xc6\xfd\xa4Bn\xfd\xe5\xb8S\xb9\x1cC\xd9\xc9\xd8\xc5\x88\xf7j3\x0fu\xb8\xfd\xfc8nI\xda\xfb\xbdD\xbc\xcb\xca7\x94'
        b"U\xe6\xbc\x03\x91=\xef\x9f\xc4\x99\xa3h\xae\xa2\xceh']\xbd\xa2\xae\x8fi\xa3\xf2\x010\x02\xec\x10Z\xcd=0\xde\xcc\x0b\xf0.'v\xb9!K\x0b\xf0}7\x88A\xde\xd3[Y\xbe]\x93\xae\xbeK#O\xefY"
        b"\x94\xb7V\xac\xfc\x05\xc3h\x86U\x9e\x1a8\x9a\t'\xf3\x95F9\xe8\xa3\x1b\xa5\xe0\x1d:\xb33\x14\xef\x1c\x01\xabH\xccc\xc4=\x8f\t\x88\xd7\x14\x1c\x82\x90{m\xe0c\xf8\xd5,\x867`\xf0\x80u\x02o\xcd\xaf"
        b'ty\xda\xe1\xe0\x99\xfdg\xc3\x0bneR\xb4\x15\xa2o]@\x12&\xf3\x07\xed\x86\x05\x0f\xa1\xe2o\xb8\x03\xa91j\xd8\xa1"\xf7U\xfd\xe3\xa8eM\xc5\x05N\xfa\xa0bc\x89C\xe1\x1c\xbd9;\xb2\x8a\xf3K\x1a'
        b'\x156n\x9f\x89.V\x9c4\x17.;!\x94\xd6\r\x82\xab\xacX\x93\xbaZ\xa4\x88\x9d\xba\xe1\xfd\x88\x06o\xc5\xe3\x85\xc6W\xb2\x17\xdb6d\x00\x95\x9d\x99\xd2\xdd\x9e\x81\x7ft\x04\x8c\xe3\xb4\x14\x0e\x98\x9d\xb5\x8c\xdfG'
        b'\x84\xe1\x00\x066\xf3(\xbb\x95\x88S\xd6\xc7\xb9\xa1\x1b\x14X\xb6\xe8\xe8N`\x81T\xe9T\xb1\xa4l\xee\xfc\xa8\x9b\xd3\x9b\xf6\x8c\xc4\x15a\x18\x11&^\xf6\xf6\x1d\x10\x16\xa8^\xae\x0c\x1cV\xab\xc4\xf1^\x1f\n\x94\x1c'
        b'\x05F`\xc5k\x9b&\xc4\xec\xcax\x9f\xa2H\xf9_\xc5{l\x8fT\xd4\xf4]\xaf}\x92Q\xcc\xe1\xce/\xcf1\xeb$\x9a\xa9\xa8cz{\xbd\xb8\x8a\xd7\xcb\x9cG(\xe3\xeb\xac\x855\xf0U\xdcC$\xd5Tvz'
        b'E\xc2=V:\x9c\x9d\x0eh\xc9;\xc1\xbf\xbf0\x10\x80\xd5\xf2~\xd6\x7f\x0b^i\xe5\x87\xdd"\xe5&\x1b\xb9\xca\xd6<?^\xa8\x1f\xaa\xd4\xd1\xa7\x08\xed\xa6\x03&\xd2\xcc]a\xda;|\x0b\xf9\x11R\x80\xab\xd1\x84'
        b'G\xe9#\xab\xbf\x83\x1a\xc23)]\xbe\xaa\xac\xafZ\xa2\xfa\xdfZ\xa4\xdb\xa1\xd4\x0f]U8U\x82\x17\xea/\n\xbe\xcfK\x12\x96\xcb\xb5\x91\xcf"\x8f\xe6 \x93,@\xc4\xd3vG\x0b\xd6\x8d]\x0cH\xa1\x01;}'
        b'\x14s\x19F\xbf\xf5Eo@\x81\xd5\xab\xed\x1eX\xd1\xfe\x12X\x8aD\x94V@E\xd0W\r\xa2\xf1BM\x862d\x83z^m\xddP\xfd\x10\x99}\xee\xcd\xe4\x8eY)\x84\xb0\xa3\x94h\xac]\x89\x8e+%\xa6B'
        b'\x98@\xed\x93\xda\xab\x8a\xe4\xf3\xe0\xd0T\x12i\xcd\x99\x84\xac\xcc~K\xef\xa8<N\xf2\xeb1\xf0\x8b\xe9~\x9b\xcab |\xce\xbc\xb2W\xee\xa9\xe2t\xeb\x8af\xf6:PX\xeb\x91!\x7f\xc3\x8b\x1a\xf8\xbf$*\xf9'
        b'\xce\xbbwN\xa7K\xfc\x0f\x10\xbd\xe7h\x1b\xc0\xb9\x1e\x13\xdc\xe7\xa5%\x10\xf5\xace\xfa\xf3E\x08\x8a\xcaD\xf4|{\xdf\xc9S\xec7u\x9ea^B\xf0C\x1f,\xa3\xf1e\x95\x0f\x0c\xc4\xb7s\x91\xd1)\x90Q7'
        b'\xd6\xfe\xaa\x9d<E}\xf5u\xb4\xec\x13\xca]!A\xe9\xd6\x98\xfd\xe4\xc9\xd9\xe9RY\xb3\xe6\xf2\xc7ZE\x17\xf0\xa5\xf6\xcf\xae\xe7\xcb\x9a\xe7bk\xe5\xf5\xe8\xa7p\x0e\xf4b\x9e\x8c\xb7\xdb+C\x00\xa4h\xab\x05"'
        b'\x02j$\x1e\xd7;n\xf7zNx\xf1_\x10.;\x0ct\xea\x81\x92J\xf2\xa3V\xcbU@4]\xb6x\xdb5\x1d\xf2|ZP\x89\x97\x06\xb03\xa94\x81\x16\r.\xad\xfb2\xb4X\x9e\xd2\xbd\xd9\x9eR\xe8\xfc\x9c'
        b';\x1d\x12\xda\x94\xed\xaa\x8e\xe1\xa8\xbd\xc0$)u\x16\xd3kW\xa0\xce~\xbd\x96\x80\xa3\xf5\xc6N?v.3\x97\x06f\xe7i\xe7\xf5\xee\xa5\xed\x80=I\xe7E\xba\xde\x87\x935\x9d\x0b2\xfb\r\xeb\xc6X\x8e\xbb\x9d'
        b'%N\xa3\x1f\x88\x1c\xa0\x880\xd0"Yk\xc4\x9d\xe3\xf5\xfb\xa3\x13i\xb3\x9a\xb3a\xa5\x89\xa9\xc6\x83@\xc36\x06\xe3\xcf\xddPZz:\'JUr\x9e\x05\xf6c\x85\xde\xe7Z!\x19Yo\x96@8\x96S\t\x03'
        b'\xa8{9\xf8n\xee\xe3\xf7Cev\xe9\xea\xdc\x18\x97\xc5\x1d4\x81\x0e\x8b\xa0Z\xd0\x07z\xd1\xdc\xf3U\xae#c\xc9\x14\x0f\xb0\xa6y?k\x82-:(\xec~^\xb95a$\xb3\x83\x9d]b<&f)}\xfa'
        b'#\xfeX\xac+\x99\xe5H\t\xb5u\x991\x10\xdf\xa9B\xa3\xf5[H\xf3\x1c\xbf\xad\x0cG2R\xf5\xeb\x1eK\xb4\xe1\xbe\x9f\x15\xec{\xb3\xcf\xe8j/\xa3I\x89\xec%\xd1\x14\xe0\xa12\x07\xe4_\x85\xb6\xdf"\xbf\x88'
        b"\xea\xc7\x16\xe7P\xcfs\xd8\xdd\xf1[\x19\xaaE\x9b\xe8\xe4M\xc6U\xb1\x82\x9e\xf1\xfa\xf7p\x9e\xb7\xf5es\xdc\xfa&6\xa9L\x95\x95\x861=\x13\x08(\xbaK+X\x05,\xb4H3\xaa\x00m\x15{'\x16\xcc\xa5"
        b'\xc9\xffM\x92\xbd#\x00i\xe8CBR\xd5\x1e^\xe4x\xb3i\xad\xff\xc2\xe9\x00\xcd~;Jt\x9f\x16w?\x87\xcdh\xd4\xa7c\xe34\x0f 6\xc2\xce\xc4. \xf7\x13\xc3\xae\xba\xa0\xf9\x01\x119H\xc43\xb2\r'
        b'\x99\x02\xc9\xe4\xde\xce\xe09\xf6K\xbb>\x8dt\n\x01%\x82PB\xee\x8cc\xb5\xdc\x9fj\xb0\xaf!=\xa1\xf2\xb5\xddd\x96\xd89\xf1#\xfb\x03\x13t\x91|O}~\xa8^!B\xb80\xc2\n\xc9\xd2_+\xf6\xb4'
        b'\x04A\x04fV3\x84B\xb3-^\xf8\xa4\x95\x9b\xb8R"\xab\x14\xf8\xb6~\xad\xb1B\x9en\x08pt\xb6\x0b\xb1#^E\x12\xec\x11\x8b\xc0\r\xa5\xbd\xfa\x96\x89\x1e:\x93\xa6\x9bZ\x05{\x89\x12\x18\xf9\xb7ug\x80'
        b'\x10,T\x8b\xd2[ga2\xfb\x183\x99^\xc4\xb06\x0e\x94\xceI\xd8f\xcex\xeb\xf1\x15\x90\x1d\x0e\xb0\x8dCP\x94\x03\x12\xe0T(\x9b\x9c@,\xe3\x8a\x98pA\xd2\xa4^\xa232s\x8b\xa1\xd5j^5\xff'
        b"0=\t\xa5\x14\xf3\xcf\x88{\x1c\x1c\xd1\xea\xe9'5A\x8e\xdd\x96\xb3\x8b3\x17\xc6O\x16\x8c\xfeo\xfe\x84i\x03;\xb7~\x04\x10\xbe\x1d\x8e\x9c\x13w\xdeH\xf7\x0f./-\xa3\xe5u\xc8N\xe5\xfdU\xc0\xe3.\xb4"
        b'\x0f\xf3\x81\xfa?\x85\xda\xb26\x93R\xf6\x0cl\x1c\xd9r\xdb\xe7\xb7\xbd\xcb\x8c\x19\xd5mz\xd8\x9c\x0f\xca;\xbdS\x17\xf1\x85\xfeN\xed\xab<\xb75\x9dGYU\xad\xff\x03\xa7\x83g\x8b\x82i\xd3\x9b\xb9\x9fP\xf2\xb3'
        b'|H|/\xb6\xb72\x1bx\xf7\xbb\x92pl\xb6\xe1\x88\x11\xef\xc3H\x9eq\x1a?\xdd\xe0\xdc\x0c)\xd5\xa3\xd4DB5\xfd^\xc4Uj\xa8$\xce[Xg\xcac\x06\x95t\xcc\xe0\xfc\x06\xbc\x84N\xe41\x1b\x82\xad'
        b'F3r\x17\x8d[\xc11\xa0\xd8\xee\x9aQ\x07< T\xc9\xb4\x1cR\x90\xf0=\xb0Hg\x1as"3[b\xbeY\xb6\x0f\xb9\xf0`}x5w\x8b\xde\xf6\x80\x92\xa3\xb4\xac\x18\xc7\xaa\x1b!`T\x99\x0er\xaa6'
        b"$r\x9a\xd2\xe4\x17\x94O0\xe5W5\xb8\xea\x04j\x11\xf2#|B\x07\xb9\x8e\r\x86M\x94\x8e\xfc\x85(\\\xe6\x88\x80\\\xcc8c\x95/T\x88\x8c\xab'\x9cfy\x10e\xa2W\t\x90\xed\xc8\x0e\xffI\xa0\xd1\xc4"
        b"\xa7]\xa9\xca\xf1u\x8c\x86\xd1\x854\xe5\xd53\x13o\x13\xb0\xe5\x85*s\x11\xd3:g\x0c'\xa6\xe1\xe7\xeaF\xafQWQ\x011\xc0\xd66\x92\x1b\x1c\x03QM\xb0\xaa\xa0\xc3\xd9gmI\xc4\xe8\xe3\xbe0Zj\x96"
        b'\x08\xcf+\x90#\xa6\xf1x\x0b\x95:5\t\xc7t\x85\xe0\xabiMG,\x81?s"\x95\xe4(\xbc\xa2:Te\x1a#!;J\xc7\xc3*\x00\xb5\x8cvI\x90\xcc=\xc6|7\x81\xfcBi\xfa\x0e\x80#;\xffw'
        b'\xe07#\xde\x83|LC\x158\xcd\xf3\xff\xc2\x03\x12>9\x8a\x97W\xec\xe7\x01\xd3\x01\x98\x08\xe4\xa0\x8c\x14B;\x83\x9fqD\x9a\x8a\xfb\xb7\x84\xcf\xa0I\xcc\n5\xea \x08CD\xc1\xb5\xda\x94x\xf9\xad\x01\xa9S'
        b'\xfb\x9f\xd5\x06\xb0\xdd\xc0q\x01\x8bszn\x94lL\xf4\xec\xe5\xdbhI)\x0b\xd8>\x97\xb6"\xdeD\x14"\xda\xc4\xf2\xca\xd1\x7f\xfcy\x87\x0c\x1f\xfc\xe7\xba\xbal\xe7qn\x88\x18\x9dm?Xg\x86&\xe7\x9b\xeb'
        b'\xfa0\xb9\xfe\xd8\xd3\xdd\x9ca\x13\x9d\xa4\xc5\xa6\x9c)\xf0\x99a\xce[\x1d\xdf3\x81\xe9\xcc\xfe695\x18 \x11\xb5:\xab\xd6\xf0\xaet.8\x86\xe3\x87\xbd\xa7b\xf4\xfeB\xcdY\xc1\x8f|\xf6_\xeeW\xdcTY'
        b"o\xcd\xddx$\xc5\xa9U(l\xc1\xb0/I|@~6\xf6\r\xed\x93\x9a\x98\x156\xa4kpW\x97'\xd9Td\x88\xb4\xc4g:l\xc0\xd1\xd9:!\x08\x90~\xb2\x96\x9a\x1c\x8b\x8b\x99\x93o\x80cJfo\xec"
        b"\xb7g\xf9\xa52}\xf8\xcd\x98ha\xb8\x9dg0\x13\xa3:\x11\x03cf*\xd4\xc4UC\xe5\xb2\xd4\xa4v\xa9\xf8\xa1\xdf\x13\xc7ojYo\xe9\x97\x90'\x97\xf1\x07\xb7\x8b}\xdb]\x00\xeb\x1c\xf5\xb42=\xb6\xcf\xdd"
        b'\xa9\x93c\rFM#\x87\xe0\xab\xdd\xd4\xf5\x9b<\xaeU\xe7f\r\xfc\xa47"S\xf4\x93\x01e\xce)\x95\xbc\xa3\xc3\x85\xa4\x8a5!{e\xd5<P\xc14d\xb7\xd99\x87\xb7\x8e\xaf\xfeC\xa7\x99\xda\xe8\x81p\x95'
        b'\x0f\x0f\x93\xab\'\xe9a\xf8?\x9fR7\x8eWG\x1a0\xd8\xf5u\x90\x08\xf8\x1d\xfe&\xb5\r\x1c\x9d\xe0\x80%\x10\x84c\xfb\xd4\xca\xbed\xcb\xeb\x86\x04\xad\xbc\xb2\xf3\x84\xe4\xe6\xf7\x1e6"V\x81\x07\x97FB\x04Q'
        b'\x9b\nQe^OC\xc0\x03\x1ci\xa7\xfe\xd9`!\xf5\xbc7~\x99\xb4\xaf\xef\xa9\x1f\xf2\xf3\x90F\\B-J\xd7O\xba_\xf4P\x7f\xd96\x90\xa1]%\xbb\xf7,a\xd8&J\xf2\x16\x98\x97\x0b\x8bDrk\x82'
        b'xX\xdf\xe4\x9b"\x98\xdc\xf48\xda+\xdb_RP\xc96`\x19rM \xf2b\xbb\x97V\x89\xc2K\x06\xd6V\xday.\xff\x0f+F\x11m\xee\xb5\x8a.\x96\x18\x00\x13qFu/e\xbd\x8a\xe0\xf6\xc0c\xaa\xab'
        b'm\x8c\x9b\xb6\x9bM>\xdcw\xc9\x83L\x91\xd062\xd7\xa9\xd5oX._\xde\xa3\xd8~\xc6`\xc5\x1b\x97/P\x84\x0c\x12\xc4\xd09{\x14\x9f\x05\xfd\xed\x9b\x1e\xa08\x9a\x1a+P/\xde\xadW\xc0\x97\xfc\x08\xf8\xff'
        b"'`\xda\xab\xac'\xa0R\xf5\xb6\xcb \xc1U\x8b\xaa\xa8\xc8\x90h\x80\x8a\xf3/h\xacC\xeb\x8f\xab\xab\x15\xfd\xdb\xf2\x13\xc6K\xa4\x91i\x854>\x98\x19x\x1a2NO\xf3x&\x8c\x1dEz3\xdb_Vf\x9f"
        b'\xd3D7}H6\x80\xc81\xf9\xab\xcd\xa8W\n\x13\xc6\x19\x91\xa5\x9c\xe9\xf9U\xb2A]\xea\xb2\xf5\x1a\x8d\xfc\xed\xc4\x804\x19\xe6\x96\xb1\xb9\xa0\x0ef\xdf\x8b\x8a\x82pI\x91\x08\x06\x03\xd4j\x18\x9a\xf0\x13;M\xa7'
        b'\x146\xbfD\xa3\x9f\xe4\xa4\xaf\x8e\xff\xb3\x83\x19\x8c\x93I\xcf\xb2\xc7\xda\xb7\xa3K\xf8\xad\xa0aM\xae\r=d\xbd\x15\xc6\xe0\x07\x8eu"\x9b]\xcbN\xa3\xef\xd0\xb3\x16z6\x94\xbb\xa2%B\xcac\xfc\x16je\x9b'
        b't"\xb12\x01U\xd3\xae\xdd\xaf\x9c!pq\xb3\xc5\xc6\xcftE\xb08\x14-\xec\xbf=\\\x81[\xf9\xd9|\xfb\xbe\x89\x12\x0c\xf84\x1d\x13\x0b\x80\xbdC|l\xba&\xeb\xc7\\.\xc7\x16z\x9f\xd0h\x87\x8d\x19\xe7'
        b'\xbc\xffk\xab[\xa9\xeb8b\x99[Q\xaf\x87\xe1S\xab\x1d\x8b\xe3\xb2\x82\xbd\xc6\xdcK\xb2pH\xfb\xb0\x7ff&B\x93\xbc\xbeC\xfaO\x01I\xd6N\x1a\x00O\xd8\xd4\xb1Q\xf2#\xea\xa9\xc8pw\xdb\xce\x11\x96L'
        b'\xb0Z\xd8\xb2\xd2l\xf6\xe0\xfa\xd1\x90\xe4\x1fy\x0f\x8c\x91\x1d\xc1\x90\x10\xcdP\xdb\x05\x0e\xca\x11& \xfc\x80\xb4\xf8!\xce\xe4\x17Zo\xf5\x06\x13\x88K\xd8\xdf\x85L\x965\x1a\x80A\xb30\x03m\x00v\xf6\r\xba\xeb'
        b'!k\xd4}\x06\xf9rg>\\B\xf1~\xaaf\xabK\x11\xccYK\x11\xf7\x9e\xc7x;\xc0J\x92\xcb\x05\xf3\xaewEu 1\xce\x8c\x89\x14%\x97H\x13\x8b\xf6\x8b\xb0\x8f:\xa1|\xb9O\x91\xee \xf7f)\x11'
        b'\xc4~6o\xfb\x8a\xf6\x85\xa9s\xfb\x86\x91\x9b\x05\xceN\xfb \xe5z\xf7Z\xce8\x06]\x118\xe3\x14"@Z\x12\xb9\x19\xc6\xf7\x93\x97#\xd5\x93\x8e\xb9\xe9\xb6\xf4%\x13\x99<T`\xbb>h\xa0\xd2x5\xc7A'
        b'i\tE&He\xd5"\x1d\x0f\xf3\xdc\x17\xd6d\xe3u\x10\x90\\D\x8c\xec\xeac\x07\xf2\xdf\xa7"\xf0jU\x0cU\xa3z\xe0\'\xa3H\xd3\x08\x91\xe6\xe6\x1b\xb2\xcb\x9d2!;\xad\xe3\'\xac\xfd\x06>7\xd6?\xa5'
        b'\xb7\xf2\xea3\xa3s\x83H\xf0\t\xfd\xdc2\xddR\x87\xe2\x80"\xed\x17\x85T\xfc\x7f\xc1\x1e\xe6\xfb\x18\xd6\xe1\xa4\xaf\xa6\xc0CF7\xda\x03Y?F\x9f\x99v\xb0vk\xe5p\xbd?\x15\xd9,\xe4 m;\xab\xe9\xa7'
        b'\xfd\x86\x8f\x1a\xdd\x0f\xaa\xc2R0\xe9g\xaarL\xef`\xa3\xd8\x92\x13~\xad\x05\x1a\\<jc\xdax\x98\xad\xd5\xf4\xa6\x00<\xec\xab7\x83J\xdc\xef]\x15\x83\x81\x92\x92\xfdWn\x8f~\xdc\xa5\xc5\xbc>iE\xd5'
        b"\x8c\xfb u\xe1\xa1qY\xc7\xd5PG\xe3\xc5-&x\xefQ\t\xb7\xe9\xa6\xbd;\xc9\x1b\xca\xe0\xc2\x8b\xff\x96\x14\x8b,\xb1yM=!V$\xd0I(\xf5\xd2q,\x12\xb5C\xba'\xfc\xc8J{z\xc6>)\xe6"
        b'Tn\xdb-k\xb5hi\x1bF9\x0c \xb9X\x85\xaa\xa8\xe89:\xc9j\xeejy\x9aT\x99\xc2D\xbb\xa8\xa4\x1f\x86\xc8z^\x8b\x91\x00\x83\xb6\xd3\x82\xb1}\x9bW\\\xeb\x0f>\x12T@IE\xa3\xe87\\\xaf'
        b'LAA\xc5e\x00\x8aH;\xa1d\xca\x08\xa3\x1c\xf8N\x8b\xb9\xdf,\x94Wr\xc7\xd4FZ\x0e\xa3Z\xafG.\x1c|\xa8b\xa9\xb8\xe3l\xac\xc2\xd5\x10\x92\x9b\xdf\x16\x9eB\x05\xc8\xee\x9f\xab\xda=@\x91\xbd\xc1\x08'
        b'\xdf`G_\xf7\x16H\xc9\xed\x8b\xc0nlYF\x18.l\xc7\xads\x91\xbbez\x8f\xfcMS\xd3\xa6\xce\xd7(\x1d\x92\xd4$\\\tW\x0f\xdc\x85\x11!\x17\xa0\x89\x07\xec\x07\xf5\xb1\xf0\xd98\xdd\xcc\xd0\x19\xc5\xd2\x13'
        b' \xb7\xe7\x9bZ\xe4\xfd\xc9\x7fZ\xc4(z\xc6\xb6\xdcj \x7f\xe1f\xac\xbc\x00w[\xc9\xc01\xbe\xcc\xff\xd8\x8bx\x83\xe5\xf4M\xc9\xa5\xadc\x00\xfb\xc4\xef\x94\xbc\xb8\xba\x94`\xf4\xfc\xe0\xe0\xfc\xce\xc7f\x144v'
        b'Yw\x8f[O\xc2\x06\xfc\x07I\xac\x13\x1f\xfax\xc7\xad\xa4+\x1dl\x93\xe4\xf6|\xf6\xb2\xa8-\x16-\xf7co\x1c\xa5\x07\xf1\xf7\xb1\xfa\x8a\xd7e\xc3~\xb7{\xe3\xcav"9B\xf1c\xf2\xdfG\x1ay\xe4\xf7\x14'
        b'g#\xbd\x82q\xae\x8dyQ~y\x9b\x1e\xec\xabno8\xa3\x84\xde\xe5\xca\xb3\x04\xeb\xd9kPLm\xf2=T\xcf\xb7=\x12\x14\x88\xd1\x80\x0e(PL1\x19\xf0\xca\x1f\xb9\x99\xf9\xcd\x11\x91\xb5\x99\xbb\x0b\xf7Y\xaa'
        b"M\xe5\xb1\xbb+\x95\xdb.MGIf+\x93\xf7\xd9>\x1f4Y\xad\xd9\xeamA\x8d\xb7\x04Yv\xf4T?\x88\x8b\x83\xb7U\x1a\xa4\xa9\xed8\xa4)\x88SJ\n\x03\xa5\x9e\xec\x18'\xe1\xe5\x8aA^|U?S"
        b'h\xf9\xfdb\xe24L\x83\x8b\xfe\xca-\x08\xd2\xf3\xc8\xf5\xa9\x17\xfaZ^\x0b\xe4\x8d/B&\x0c\xbd3\x95jY\x18\xde\x96j\xb5\xa1\xfb\xf4r\x84\x0c\x9cvr;c6&\xa1oR\xb5\xc9\x9b\x96-":[\xed'
        b'S\x98\x85\x0e\xf8A\xfb\xd1\xaa\x9b\x9a\xefC\xaf\x12\xda\xe6\xaa\xf7DK\xba\xc2p\xea\xefN\xd7.c\xaeo\x1c4\xb1a\xc7\x0e\xb2\xd4\x07\xaa8\x94\x89l\xd5\x08\x85\x89\x00P\x9f]\xcd\x99\x07\xda^\x17\xda\x96\x01\x83'
        b'j\x0e\xe8T\xf4#\xb5\xb5\x01\x17b\xba<*\x03_\x1a\xaa\xf2\xf1\xe9\x1a\xbd=M\x18\xf5\xa3\x18\xc0\xa0k\xebq[Y*\x85\x11\xc4\xe8f\xae\x86\x1a\x01k\x80\xe3\xd9\xff\xca\xbaj\x10\xd5\x16\xd3\x8b\xf8\x9drRW'
        b'E\x94+N\xc8\x97y\x91\x19&B{P\xdaL\x80\xc7\xd0\xc1Y|\x1d\xac\xaaE<\xc9O\xc5\xc8\x1c\x14\x9d\xbb\xfe\xbb\t\xde\x06>\xadh\xe8\xfa\xb5.\xb2\xccO\xf6-\xc2\x94\x07db\xa3All\xcf\x1c\xa0\xa4'
        b'*)R\xb7\x13?1\xdd\xfe1\xf8\xca\xebw\xe3\xf2\xcb>\\e\xdc\x0c\x12\xb6rk\xe8\xc1\xb0\xd1\x19Wa\r\x1eM\xf8~\xfcQT~]x\xd2Z;~\xfd&\xc5\xc5\x0bq\x9eU\x9f\xf0\x91:hP\xde\xe1'
        b'\xdc\xd4 \xf0\xb1i\xa3o\x9a \xf0#\xfb\x18\xa5\xa6\x90\xf4\x87X\x92\xec\x8a\x89$\x08\x003\xc5\xe3?l\xd6\x87rb\xd3\x8f\xd9R)\xd8>o\xdae>\xed(\x06h\x01\x83\xae!E\xa1=\x9d\xba\x93\xe6Y?'
        b"\xf4bN\xcd\x97\x98s\xfc\x93m\xea)\xcc\xea:\x99\xe5@\x83\x8c'\xdf[\xd2\xbf\xceU\x0f\x9a\xdcj\xbf\x96Z\x93i\x9d\xd8\xf1\x93d\x9f\xc6\xacg\x872\x98-H\x12\xa4\x1cnM#\xf2\x18\xec\x84\xb6\xab{\x8d"
        b'\x854O\xd3\xdcm\x07\xb9\xb0\x8d\xd3\x06\xbb\xb58\xb7{\xe66\xb9\xb7/\xb6`\xf0\xc8\xbf\xeeX\xd8\x81\xa7\x82xEp5\xe2wF \xc0\\\x90\r\x17\x8c<f[(v\xd9\xa3\x97\x06)Bm\x84\xadWlx'
        b'\'\xef\xb6\xc8\xbd8\x8cz\x1a\xd5\x90\xfd\xb75Ll4\xcfR\\C\xb9\xec\xe1\x9c\xbc\x95G\xedv\xa2\x1aJ\xd7\xd1JMg\xa0\xa8,\x03\xc0]<G\xc0?O\xac~\xfb"\x84\xe8\x8b.\xf1\xf0\xdc[\xb0ez'
        b"/p\xaf\x12\xaf\x94\x0f.\x90i\xb8\xc6\x15\x9dH'DX\x8dA;\x1a\xa7N(P\xb7\xcb\xdaVS\x1c\xeafc\xf3\x1aC9?\xcbG\x90\xb3\xa1\xcf\xdf\xf7\xa3\x80\x1f\xe6\xcbo\x9d\x8fr`Y\x1duu\xd8\xaf"
        b'\xa3\xc4\xb4\xe3\x82\x03)\xffId\x80To\x82<a\xb6\xad\xd3\x03\xf7jg\xb1w!A\x13\xa4VR2\xb86Z\xc4\x0c\x1f\xa5SNH\xcc\x9f\xe4?*\x02\xc0\xcf@\xfcL\x964\r\xef\x0e\x982\x01\x06\x8f>'
        b"\x87\xf8L9'\xef5\xfcV\xdd \xbc0\x190\xb0#\xe2]-&x\x81\xcc\xa1\x93\xce\x8b\xeaX\x94\xd7\xb9y-\x1a}\x87m\x08\x01\xb5\x9b\xbf\xb4\x98\xcd\xa5?r\xf5\xbb;\x8c\xc3\x8f\xb1\xb7\xd89\xf1\x90\t\xcf"
        b"$B#U;\xc1(Z\xd1\xdd\xf8#\x8b\xfe\x9b,\x0co\xe04U\xf5be\xbalvB\xe6\x993\x08\x9e\x06s{\xa1\xd7\x11=%\xe5\xad*$\x1e\x0fQu\x02\x10\x13'\xf0\x03\x95Y26CP\x8c\x16\t"
        b'C~\x89\x1c/\x0f\tSP\xf9\x9b\xd1\xac{\x1bT\x14\x10\x1b\'k,9T\x1b\x01\xd82DSA\xa4\xa6\x11\xc95\xd6\xdc\x88"\xd7\x7f\xe8\x86\x01\x97b\x0b\nBAo\xbc\xd8,\xfd7\xed\xd1\xa5\xac\xc6\xc15'
        b'\xdemk\x03\xd2\xc1"\x1e3{\x000n\xddWI|\xd6\x93\x14^\xae\x89qd\rs3\x8c\x16\xf0\x8a\x1f\x82\xfbN\xc7\xdb\xf2d4\x87\x00G\x98 \x1e\x85\xd2\xab\xf1\x05\xd5\x8b\xb9\x15[\xe8\xfe\xfa\x81"\xa7C'
        b'\x89\x1ctvqI\xdc\xef\xcdL{8\xb2\xbf\n\x93\xbb\x86\xb8\xe7\xb4\x1d/>\xc2\x18R\x9e\x85*\x8cw=\xcd\x88BS\x96\xf2\xafo\x98\xe7\xd4\x11_nA\xe1\\jz\x84Ey\xb9\xec\xb7\xa7V\xf0\x07\xe8T'
        b"\xce\x98\xca\x87\xa4O\x18@{%o\xbe~90\x9f\x90XE\x0b\xebV\x19Rmy\x1e\xb4~\xeb\xa0/|&\xa3\xba'\xe0\xbcI\xa3M\x166!\xae\x00\xbe}\x0e\x89\xce\x1b\xd5\xe5ia\xb6Q\xc4\xd6\xca\x9e\xf9"
        b'wkiu\xf6\xd4I\xc9$\\z\x9a\xe6\xb2\x07\xfe\xd7\xd4UL\xd9\xcf\x15"Y\x98c\x9c\xf2\x9a\x92\xb1\x91\x13&\xd0a\x9a\xa8\t)5\xf8\xe17\xa86\xcc\x15\xca\xe3\x88\xe9\x84\xcc7-\x86\\\x14\xf0\xa3/M'
        b'\x0e\xa4=\xbe\x89\xedhP \xa6\xa1g\x9b\xb1o\x00e@\xee\xd7\xad\xa8y\x87"+\xe7Ja\xbf\x04\xd9\xcd\xca\xfb\xa6\x80\x1fG\xde\xd7\xe9u\xe8\xa1\x9c\xa6\x81\xc3F\xab5MD]\xd9+I`g\xc6\x1f\x94~'
        b'7\t4]F\xa6d\xb6\xfe\xc3\x8a\xbb\xcc,\xaa\xa5r\xec]\x99"h\x830\xe3>`\x16\x83>\x91\xf7\xe1\xba\n\xf1\xf8\xe2\xad?\xd50E\xfa\x8c\n\n\xf7\x97\xdd\xe2A\xa4#N\x03\xa0r\xa8z\x8c6\x0f\xfb'
        b'\x12\xa7\xc9\xc3\xe7\x10\xb4\xdccTSxo\xbd\x93?\xde\x08\xde\x95\x89\xec\x13\xa2\x05@1u\xb9\xbc\xf5\xf9\xe8T\xda\xf5\xbfl\xaf\xc2\xfd\xd0\\`\xe7\xb8\x19\x88\x83\x92\xe2\xe8V\x8a\x0b5\n)1I,\x98"\xef'
        b'\x874\xbf\x8a[\x05!\xaag\x98\x87\xc0\xcd\xf2K\x13\xbb\xf2\t\xa4K\xe32b\x82\t\xd8\x17\xe4\xef\xa3\xda6\xd3\xd5\xceT%\xdb4$tn\xca\x9f\x0fF\xa1\xe3\x17n(\xca\xa89\xbbq\x99o>\xed1\x7fa'
        b'\xcb\rT\xe5\x92plR\xa9$\xd5!e\x01\x8b\x86H\xa9\xaeO2\xb8\xa5\x82\xe7rx?r\xd3U&\xdd\x18\x96/xy\x1c#\x87\x8a\xa9T<\x00x\x9b\xecFn4|T!X\x17\xbb\xcf\x11\x03\x95\x10]'
        b'\xf8\x1f!\x82\xed{EtE\x10}K\xf8\x87\xfc\xbe\x08l\x13;\x98\xbc\x9c\x8br\xdf\x1c\xfc*\xb5\xd6\xdf\xaa\xae+\xbdB\xd4\x88n\x9a\xf3$\x1e\x8c5\x0f\xf0FoF6\xda\xa9I>e\x13X\x81\x12x\xd7\xea'
        b'\x15\t\xa2\xc4\x10\xa7\x18\xfbM\xca\xe09h`\x98\x01\xef\x042?\xb9!GP\xe6Y\xc9\xd0\x9d@\x8f\xa1\x19J\xa4\xbdW\xfe\xa0\x03\x83\xaff\x02\x98N\x9f\xf2pG\x80\x89\x952%3\xed9\xe7\xb8h%b\xe7'
        b"\x95\x87\xa8\xd8=q\xdd\xd8\xe5b\xbdX\xdbm\xf7\xdfh\x9d\xfb\xb1\xe6[\xa0\x0f\xf0I\xae\x8d\x81\x8a$\x81\xe3+\xf6\x19F\xe1\x9e\xe0\xe3{\x9b\x96\x9b\x8b\xc3\xda|&n\xc4(\xdbm\xec\xd2s^'\xe0\xc9\xec\xdb"
        b'0@\xc2\xc8\x90\x9cD\xf5\xd5\x84\x1cPS\xea\xbc\xc5\xb9\xb7\xf6N\xb3\x87_\xa1\xd0G\xc7\xbc\x816\xe5\xb5\x1be\x93cF\x15\xf6\x0f\xf8\x0b\xb9\xf7p\x8di3\x08&\xe9F"BT\\\xa3\x05\x11\xa5\x81\xa9\x1f\xc9'
        b'\xb3\x1dU\xf7\xae\x82\x82\x03\xd6U\x90!\x8b\xfa\xcf\x04\xf4\x03\xa0\xaaH%x\x19\x14I[\xc8\xbebd\xa0\xd6m\x85H\xd5\x08t\xc9\xc4\xe0\x1d\xfeu\xa3\xa60\x8fn\x12\x8a2K\x83NNl]Dsj\x14\xba'
        b'*\xe0p\xc9\xda\x8d\xfa\xb2wOl\x1d9%V.\xceJM\xf1:@\xb6m\xdaR\x89r\xc5\xd0x[\xee\x1b\xce\x93Dz\x95\xd0\x8e]\x98\xc6\xde\xf2\xb0L7s\xfb]\x7f\xa9\xe6\xfc\xcddK\xa1\xb54\xa7\xd1'
        b'\xd4\x0b\xf4[\xa8NaU\xab\xec\xe7{*\xb4\xaf\x01\xef`\xec\x8cc\xd1!kn\xbc\xc3\xf0\xe6r\x18\x10\xa5\r\x0e_\xbe\x87\x90\xc7\xd0}{\x97\x87\xc2\xfe\xf8s\x12;\x87\x84^/\xab\x1e\xfa\x90\xf1S?\xedm'
        b'.\x91\xfa\xe5\xe0p\x1c\x82\x11\xaa\xb7\xe5\xf1t\x0e4\xb3Y+B\xc2\x8a\xc5\xbd\xe4\xd6\x9cP\xe8\xe5j\xc67\xc1]\xbb\xd8\xed!\x0f\x14zY]\xf4\xf5\xcb\xa9\x04\xe8\xe8\x8b\x88\x82\xf9\x94\xa5\xed\xa2\xe6*\x9b\xe6\x89'
        b'wCaR\xcb\t{\n\xbc\xf3\xf7wh66\xa1"qM\x1a\xe7\xfb\xe3\x9b,\xd8\xfd\x8f\x15\x99\xcc\xc0fA\xed\x92\xca\x85Z%\x9e\x91\xa5\xc6f\x93\x17\xc6\x10\xf5\x9c\x9d\x86\xc8Qh\xce\x95C+\x18\xd7\xc1\xc4'
        b'\xb2\x15\xf0\x84o\xdd\x9c+F!\x92\x17_\xa7T\xa1\xba)\r\x01\x808Gw0\xf0\xbb\xe5\xc4\x8b(\xe9O\xa2\xb18\xa7\xc5\x17C/\x03W:\xb6w\xef\x84%\x18?\t\x8c\xa9\xe6\xce\xdfGYro(H\xff'
        b'\x11\xe9B\x9b\x08\xa8s\xf7\x87\xc2C\xf5\xb5\x0c\x82+\x00\x01\xfd\xde>\xa9{\xfcR/\xaec\x86\x12\xb8q&\x15\x92\xcf/\xe6\xb5\x8c\xbf`6I\xfbK\x0e\x84>IB\xb6\xc8\xf8\x16\xb9e\xf8,\x96\xa2[v\x84'
        b"\xceJ\xf9\x8a\x98\xbd3\xc3\x8b\x05)\x8b\xd4\x1b\xaf\xb5D\x9c\xd6\x89\xa7L\xd9\xb7\x0b\xe5\xb6'\x08\xc3\xa3\x97\x8e\x81\x92\xa5\xb7!\x81\xa8y6\xef\x1aO\x1b\xb9\xdf$phS\xae\x01_B-\x91qQC\xc3\x08\n"
        b'\xf1Z\xffN?\xb1X\xe3p\xee\xce\x1a>`\xa6\xbe\x1a\xe5\xacE\x04\x90|\xe2\n\x15\xf8\x99\x87\x91\x8d\xa2\x9d4\xf9m\xb08\xee\xf8\x14^\x05\x8e\xcd\xf0\xf7\x87iK*W\xdb\x9a\x07\x100(\n@z\x8c/C'
        b'\xe1\xa8G\xa3u\xbe\x80F+\xc9P\x81\xef\x98\x1f\xf3opW\xa8N|4\x01\xd2F\xed\xb4S\x06\x02\x0crD\x9b\xc1\xcb}\xc6sm\xb9OMiW\xf1\x02\x896\nB\xaa|\x1f\x89k\x10\xc69\x07m\xd0H'
        b'\xc5\xc7\x9d\xe1\xeb\x1fya|2E\x12\x7f\xcd\x7fj\x17\xa2O\x889\xf0\xce\xe7\xda\xa8\xbb\xaa\xa4\x95Q\x0b\x0f^2\x81\xe6\x01^\x87\x87\xabg\x85\xf5\x88\x7f\xac\xccJ\xe9\xebi\x88y.\x1a\xf8\x12\xe8N4\x0c\xd2'
        b'rAmm\x9d\xd55\xd8;4\xcbH\x9eF~\x1a!HD\xd0\x1d\xd6\x1a!\x85^\xe2C\xa9\xa1.\x1c\x8c^a\xe1fh\x90\xc2\xccG\xaf\xa8D\x9c\x0f\xb5\x10<]|\x8b\x999Ee\x82\xb1\x18\xdfx\xe9\xc8'
        b"\xdd\xaf&E@\xf2l4\xf2\x12\xcb\x9ba\x83\xd7l\xb8\xf4\x94\xeb\xcd3\xa2\x8b1\xe9\x87/\xe1\x81\xb5'~\x92)\x90\x9d9\x7fB\xc3\x9e\xa4\r\x8f-=Y\x88\xe0_P\xbf3\xd2\xd2\xdbc`o\xe0\x88\xdf\xbe"
        b'Z&/\xf0 me9q\xe9\xf1\xb7\xc2\xaf\x0c\xcf\xcf|$F\x04/\xc6k\xa21\xd0\xda\xce\xef\xd0\xf51\x14\x89/5\xda\x0b\xd4\xd3\xf6\x9fN#-\xbb\xf5iD\xaeuOV\x06\xe8\xfaK4\xe9\xbd\xc2\x06\xb7'
        b'\xa7\xbb\xda`\xcf\x03@\xb7\n\x81v\xe8\xc0P\\\xa6d \xf7$-\xf7\x03\xddrVq\xe2\x8e\xfa"\x0c8\x03\x06\xe5\xb1!r\xd0\x99\xc3\xf8\x8am\x9d\xcd\xa9\xfe\xf9\x81\x05\xca\xa5O\xea\x10\xa7\x03\xaa\xf4@j,'
        b'\xde\x89\xa4\xe3\x1e\xdf{\xee\x89\xac\x97\x04\x19;\x82\t\xf3\x7f\xcd\xe0\x1ay\xe2q\r\xc9\\\xae,\xbf\x81\xcf\x15\x82\xac\xef,\x13\xc4y.\xe4\x152\xff\xbf\x7f\xcf#g\xffJ\xd4\x9a{/\xd4.\x8e\xbe\x01;\xf4\x05'
        b'\xc4F\xb6\xeeKN^g\x9b\xb5\xed\x80\x1a\xe5C\xa6;\x88A\xf3\xafu\x99\x90\x1f\xd7\x12\xbcx68w\xc2!\n\x1b\xdf\xab1d %\xbfI\xc8\xbb\x8e\xd0\xf4\xd1\xdc\r\xa6\x9fA\x8a\x94\xd7\x13\xd0Tu\xed\xff'
        b'\xe1\xda!\x90\x8c;\xb2\x8fm\xe4|\xfe\x83\x15K\xb4w\xe8k\xb3\xa4d*\xdf-+\xdb\xea\xe0\xc0?\xd9\x80\x15^\xd2\x15\xc0\xeday\xd8\xefG\x80\x08\x14\x8d%J\\\x89n\xa5\xdb\xbf\xa9\xb3h\xa8\xce\xc7z\xa5'
        b'\t`\xee_\x02@OK\x9c\x1c\xab\x14J\x82a\xb0r\xa5\x82\xac\x1b\xebt\xa2+\x99\xe1\x04\xf8\xfe>a*<\xff\xc5c\xae\xab+\xd12\xa6\x8aI\xb4\x8bL\x82\x1ex\xa1\x17)44w\xf5\x98\xfa\x87\xca0\x1f'
        b'J\x96cj\x00\x86I\xbd\xf76\x85\x98Ro\x82vFz\x8f\xef\xa2Y^B\x92\xc2PN\xfb 3\xa8\r\x9fu\xa0\xe2\xbd\x96y\x99\xa8\xf85\x0fm\\2\xce#\xa6\x15\x98\x95\xe0T\xdb\xab\xde\x8cN\xdc.\x15'
        b'\x85jwQ\x9f\xae\xf2\xd9\x14\xb1\xa2\xc7\xd0eK\x87V#\xff\xa35\x87f~\xa9\xb5\x16\xd1\xe2T+`\xbd\x0c\t\x18E\xefKt\xe2\xa4\xfe\x17\x94\xc6q\xc4\xceP\xe0C\xf9\x96\xfb\xcf.\x9cs\x9b\x92\x8b\xc2r'
        b"49\x93o}\x1b\x04}~l\xe7\x02\xa0\xee;\xe9\x11 7q\xb2\x80\xd3B+\xac\x94\x89\xf6\xef\x11<\x12\x8b'\x85'0\x05\x82\xf3\xe7\xb7\x9ev\x16\xf5X\xfeA\x1b\xb2sv\x02\tc\x06\x8an\xa3\xfe\x84\x95"
        b'\x0b\xf5\xdfU!\xf5\xaej\xb7\xedEe\xe8WLx/\xe9$E\x07\xb7\xbe|\x1e\x8a\xcbH\xbbz\xea\x99\x89\xfeC\x8234\x8a\x18\xaev1\x7f\xb5\x9c7q\xaf\xf81$\x88\x8e+\x84d\x0c\xa3VI\x90!\xb5'
        b'\n\xf0~\xc1$-\xa3\x0ev\xd1\xcc\x18\xc1\xbf9\xc4\x1bK1\rk\xf7\xbc\xfd=\x90j\x83\x0f\xc1\xa3=\xc9l?\x93\x8bT\xb1 g&\x9b\xa6\x08\xbc\xd6\x81\x91\x02I\xe3\x9b\xee\xddbJb\x16\xa8\xdb\x891 '
        b'\xf0\x9e\xb8|\xf7o\xdd\xe59>\xe8\x06\t\xd6\x90h+\xdd\xbeq(\xe4\x90]\xa2^Q\xed\xc7\xa5b^\x90\x8a\x0fQ\xb5\xa7\x8e7\xfd\xfa\xa0\xcaK@\xc8\x96\xb4H\xc2j\xc4\xb3y-\x8c\xc1V\xb8\x05\x0f\xb9W'
        b'\xe6\x94F\xf9uzc\xdb\xfbD\xb4\xa4\xfb\x19$\xfbDuh\xff\x8a[\x0f\x0c\x92rU\x86\xeb\xcc\xf3\x9b\x92\xef_\xc7p\x10\xce\x13\x95C\x87\x87"\xcbi|\xd4\xe2,\xa9\xaeyC\x00\xa1T:\xa4\xb9<\xa3\xb8'
        b'\xd7\xeb\xe0.\xef4\xf2a\x9b\xea\xfc\xed\xc6\xd9\xf6\xb9\x19\x81n\x92\x9a-\xac<E\x88\xb2\xddd\xa5TeH\xca\xbb\xf4\x0f\x07h\t\x91\xbc\xd0f\x83\xca\xca#\x82\xa17O\xc9\x14\xff&\xf0Iw\x96\xabHd\x0c'
        b'm\xad\x9a\xbb\xae\x7f\x08\x14=\xaf\xa0\xc6\xf0\xec\x06\n\x9cx\xa1zW\x95NE\xdb\xc6/(\x05\xe7o\xf8\x9aI\xee\x17!\xbf\x81\xe308\x1d\xbe\x05\x02)\x12 \xcf0\xdf<\x7f\xdc\x91\xfbM\xeaP\x92\xffn\x13'
        b'=\xa9\x87}O5hW\xa4(B+\x1c\x12\xcby\x01V\xed$\x8c\xa4\x07\x89\xc4 \xf6\xd4\x14\x9f\xee\x91j"\xd7O\x10l\x92D\xf4\xe0\xba\x1e%&\x0c{\xba\xber#\xfd%\xb4`\x084Dv\xc0\x84\xeaq'
        b'5r#W^"\xc9\xef\xe5\xbdL%Y\xb9\xa1\xb2<\x90\xcf\xa7\xceo\x14F*\x13)\xd3h\xfa<e\xb5\xc4\xa1:J\x1a\x12\xb6uO\xd5\xb9|\x8a"M\xeb\x14n\x92V\x96\x12\xe7-\xcbXl\x11\xea\xfa\xdb'
        b'\x8d]\xfb-L\xa7\xb0\x8a\xbf|V\xe5\xa4|\xa3l\xc0\xa5\x11I\x00\x90\x08\xce\\\xa3\xe0\xa2\xef^dU\xa0/\xdd\x98\xc3\xd1\x08D\x03]\x9f\x7f%h\x81XA1b\xc2Jd\xf2j\x8e\r\xa7\x7f\\ _\x8e'
        b"R\xb3\xcbc\xa9\xaaE\xe7\x8a@\xc23|\x1c\xdc\x06l\x82Ab\xd77\x0eO\x10\xf6my\x0c>J2\xcc\x1ceb\x8c\xdf\x05\xc03d\xb5o\x9f}\x00LD\xe8\xc8\xd6\xd3\x8b\xa1\xae\xe6'H\xe4\x13\x92%q"
        b">\xe9K\x16\xb6\xb9\xc5DV\xc5,'\xc2\xdd\x97[\xe1\xefu<\x0b\x99\n+Z_\x8c\xef+\xf65\x02m\x0f\xc5\xd0O\xe0\xd1\xd2\xc31\xde\xeb\xa5\x06\x84\xe7\xa2\x9d]B 7\x8eH\xd5\x1a\xd5:K\xbds\xc7"
        b'\xa0\xe5\x83$\xc6Aj\x92\x96\xfd\xba`\xc9\xddQ\x1bj\x14-[b\xfd\x82\xc1\x98~\xcb:\xe9<\x1f\xc7\x9aj\xdc2)\xa7\x1au\x1e,\xe3r"\xf6\x02\x01\xea\x1b\xb2f\xa9\xd6\xce\xf4\xaa\x86\xb1v\xb3\xad\x94\x1c'
        b'\x00\xa7|ID#\xf2\x11l\xbd\xdf8\x80\xf1sA\xf0d`\xc3\xa9\xb5\nY\xcc\xa0\x064\xca\xffV%\xd8=-\xe4(\x96L\xc5\xe57\xfc\xb1\xc6\xe6\x99|\xa0hf\xd5\xa5&0Y\xbd\xca\x05x\x16\xf8nd'
        b':\x17\xf2:>\x91K)7`\xa7\xfb\x8f\x05\xca8f\x06O\xabDY\xf7\x12\xe7\x92\x97T\xa5\xfb\x16]\x18B\x02\x1b\x0e\x08\x07\xc7\xb8\xb3:\xd2\xea\x1d\x8a\xbe*\xaeC\xe3\x1bzXf5\xec\\\xe1\xd8\x132\xae'
        b'T*\x850xs\xaf\xa8\xee\x92\xb0\xf4\x88\n\xe2\xd3\x92V\x95\xbf#L\xd1V\xac\xecSX\xd2\x12\xc9N\xa1\x81Wm\xb1\x03\n\x8e\xfb\x17\x97\xc6,\x90\xafD\xf4\xc3\x80\xd5\xd7\xec\xc8\xb5>&\x04\xd5^\x16BJ'
        b'.b\xb2\xda\xa1\x9b\x13\xf1\xd9z9B\x9b\xa7\xe7\xc6?\xee\x7f\xe0g\xe9\x86;@\xc6\xf45\xd9~\x10e\xd4\x0b)\n>Eb]V\x95\x15E\x98&\xe5\xe7\x82\xa2\x82\xc4\x89\xfeF}\xa4\xc3\xec\xec\xa1\xd8\xc9^'
        b"%\x8d 0\\`\x08\xd7\xd8\x11\xff\xf683\x82\x1a<\na\x97N/V87_\x16\xb80\xfa\xf7{\n{\xf0)k\xd0\xba\x02\xdfeT'\x98,\x10~\x87L\xb5c\xeaU\x16\x1d\xf5\x8f\xd2Cw\xd9\xa9,"
        b'\\ \x93W\xfe"\xfbZ"I\x0e&\x83hX\xe2\x9f\xa1l\xf0\xf2\xefm\xbc\xce9\x12@bW\xeb\xf9Cx-\x8a\xddI\x02\x024\xa8zm\xf6\xc1\xf1I}Z\xc6\xac!\x8b\x05\'\x8f\xc7q\x93\xbb\xae\x8a\x15'
        b'\t~\x89\x824\x1c\x1e%\xcdi\xb4Q\x9e\xbf\xbe\x13\xfa\xe1\xd7z\x9c5\x99\x100\xf9\xb7\xb2\x84}\xbfNh\x97TN\x02\x9c\xcf\xc4\xbd\xc1}9\t[\x1a\xcd1\x82\xde)\\\x9eQ(5=*\xc1\xa8mJ\x8c'
        b'\x92\x9f\xae\x08\xf3s\xe9\x9d\x8a\x88\xd7\x06\xd2\xef|\xfd\x1d\xe6\noB\xc2\xb9\xd4\x08\xe7\x17;6k.\x8f\xd0\xf2\x0e7&\xea_\x91\x95\xca(\x04y\x13\xc3\xe7O+\xed\x05\xa60\x0c\xd2k\x1c]x\x92\xb8\x87t'
        b'\\\xf67)F}\xeb\x8e\x80e|\xc2\xdf\xbb3^\xab\xc9\x8a\x88*\x8d\xf3\x9ft\xa5gAb\x83I\xc0\xd7\xe8\xba\x8f\xad\x8d\xc4\x0e^\xb9\xfb\xf7\xf3\xe2\xc4sM\x01\\ 1\xf9I\xd7\xf7Y\xfa\xe1\xea9Q\x05'
        b'\xf1|n\x81s^_8\xac\xb6H\x9c\x8d\xa6\xad\xda\x83b\xf8\xe1W\xf7?\xb5\x93\x9a\x162\xfdZS\xba\xd3<\x9e\xe4\x16\xf4c\xb9\xe6\xf0S\xdfp%\xd8\xd8\x1f\xca\xe8d\xc5\tO\xfcK\x82\xae\xb6\xac\xcc\x1fK'
        b'E\xee\xd6\xad\xa8\xba\xae\xa0iJ\xa9\xee\xe4f\x91\xb0\x9fe\x196\xd4\x8b\x08iv\xca\xca\xcf\x80\x1f\xb2\x87\xdc\xfdNJ$\x83\xc9\x13\x93\x12<\xc3\xab-\xec!f\x99\x87_\xa4L\xae\xc4v\xaf.\xf8\xe6\x16\x9f\xb8'
        b'\x9b\xdag\xe7\xe7y\xb4\xb2p%\xc2\xeeS\n\xab\x8dW\xaea\xaf/\x9b\xe4\xd8\x8ba+\x1a{\x82\x18\xbb\xa3\xba\x87\xcf\x16\xce\x1dNt\xea9\xad\xeb\x19\xc9\xa4\x16\x18\xeb \xea\xbb\x7f\xf3:\x88D\xb6Q4\x11\xde'
        b'\xaaFtW\xae\x97\xb7,Q\xa5cF\xc3{\x96mB\x16\x12\xe7-\x18\x04\xf0\x88U\xbe\xcb\xf4\xa8\xde\xd6O\xc9K\xfaHV\xa6\xc1J\xf7fb\x85\xdfWpeg\xa5f\x07X\x95!\x1bZU\xd5>Dp7'
        b'y\xf1\x85\xb0\x18\x15\xef\xe9\xeel\xcd\xe3\n9B\xdd|\xd8(\xce\x03M\xc1\xe1\x99\xf0\xa2\xd8\xe6\xcdqP%\xab\xeem<\xce\xf2\x81jy \xa9\xdb\x15F\xf8\xf8\xcc\x055\x1f\xd5\x19t\xc2+\x1fb\xb1\xfcIa'
        b"\x13\x1c\xdc\xd4\x9f9\r\xa5\xb4r\xae\xa4\xef\xe9B\xbc\x8eH\xf8\xcc\x99{\xf1\xb2~ \x0b&\xb1\xb8G\xe0G\xa5\x95e\x17Uk91aM3E\xf9r4P\x18'\x92V \xd6\xdfd7\xb2\x00Bj}\xaf"
        b'\xab1\xc8gL\xf8G\xca\xb3\x89\x06\xe1Ac$Au\xe6\x92\xd2X=\x8cV\xf2\x1dQF\xf9)\x92]a\x1c;\x8c\x16\xabF8+\x13c\xf1\x93{xW\x1a\xb1\x03\x98\x8aH\xc5\xba\xa8\xabn\x14\xcb\xde\x05\x07'
        b"\x84\x93\x9c\x8a\xd4\x86 A\x11\x9d\x89\xdc\xfb\x00\x13R\xb9\xa0\\_xT%p\xb2\xe0\xb1\x99\x8b\xed\xa4zO\xaeQ\x08\r}\x14\xa4\xb4pB\x89\x8dUH\x93\x92'\xeegw\x04\xdfD\xf4\xd1\x7f\xfcr\x85\xc3\xf9"
        b'Y0\xd2\x8dF\xe6\x81\xe6\xb4j\x12\xa5Et\xa9#\x1d\xdc\xe3\xec\xa0}\xaf\xab.\x13\xa2\xab/t\\\xb6(!\x10\xc2"\xcd\xd8\x8bz\n\x15\xbe?\xc1\xa2A\xdbtH\xdf\x08\xb3 \xa6/\xd5\xa1\xf4\xb5\xcfu\xfc'
        b'\xaf\x9d\x0f\\\xafC\x88A\x04\xda\xbf\xb4Wj\xe1\xd8\x99[\xa7\x8d\xa7\xe9i\xaa\x04A*\xe8\x94\xee3=\xe4\xe9\xf0\xba\xfb\xbd\xe2\x07#\xf0\xa7\xe5Kd\x9cQ\x94~a\x12\x01\x8eP\xadDj\xce\xd2K\x03l\xa6'
        b"iw+\xde\xb7\x13\x90\x11\x05\xb9]\xbf\xb4\xa8\r\x05\x9fa\xa6x\x85w\xde\xe5\xc0\x87\xdf:\xcb@i\xa6W\xb5\x80\xc9\xc5\xbfHl'V \xb9k8\xceE(\xb6\xcd 1\x9b\xa7\x04\xd4e\xe0]>\x9aG7"
        b'\xd99X\xaa\xac<\xd4\xc7\xfdFU\xff\xb8r\xa6\xdc\xa3\x83>\x93J\x1e\xce.\xf7F\xcc\x84\xc2P\xaf\xb1U\x03\x0e\x8d\xfb\xc7\x0f\xaf\xe5\xc4\xbcZ\xe6N\xb4\x14\x0cLgl\xffL\x89q\xaa^\xf2\x06\xc9\xa5\xe5\xd2'
        b'g\x84\x80\x18#p\xc4\xb5\xc3\x92+\xb5\xd8\n\xf81r\x1a\xcf\xac:6\x8e\xdd<0N\x8a9\xb8\xf3\xb7\xa5b\x04_\x03k\xbcU\xfd\xdavzc\xeb\x1d\x110\xb6Dy\x8ex\x94\xe9%\x98$\x8eK\xaeE\x8c'
        b'\xac>\x92\xb1\xae\x95\xcdSB\xe61\xc5\xc6\xac"\xe4\x93b\x0c\xc3\xe5\x7f\xa5\xb4\xf6\xc2\x07\x8f\xfaAc\xd5)\xa2D\xd9u\x15\x1b\x84!\xac\xee5s\xb9\xfbG\x8b\xc9X|+>\xd1|\x0bc1\x84\xeb\x94\xb2\xdb'
        b'I\x02F\xe1\x0bV;\xc5\x96V\x86\x08:\x14\xf1;w]\xeb\x89\x1b\x89\xe8\xc5B&/9L\xb7G\xc4\xe1\xd9e\x04g\x02x7:<[\xb5m,\x93k&\x9c\xa4\xc1\xadI&\xb9\xb5\xb4\t/\xf4\x17\xf1\n'
        b"^'\xe5\t\x96{\x0e\x03\xbc\xed\xef)\xeaCZ\xb6\x90\x95\xdc\x1b\t\x81\xb09eG\x13La\xdb0h\x05O\xe2\xb7\xb1\xf1\xf1Tl\xc1\xe2\xec\xa6\xc0\xcb\xdf\xdc\xa9\xcc\xdb\xc6\xcd\xbd\xa5\x8a\xd2\xe4\x00+\x97\x02@"
        b'\xcd\xbb\xdf\xc4\xae\xcd\x9ek\xcd\x12/\x91w\xb6\xf6\x94u\xf2Z\xf1y\x8c\xb2\xd3\xdf"\xc4\x16\xe64\x92[xt{\xd7\x11OD\xc0\x0f\x86\xdb\xb8\xcc\x18\x02\xf1\xbf XF\xf9e-A\x92?\x03_\xf5$o0'
        b'REE\xa0\xf5\x1a\xd12&\xb7\xa5a\x91t\xb0\xf0\xec\xe0=\xa5\xd8\x82b)\xe5\xe0\x85\xaaRzpy\x82t\x9b\x15\x9fS\xf6\x03oT\x0f\xb4\xf9S\xac\x87\xc9\xe72\x95\xe8\xf5\xc6\xbc\xa2\xbfZ\xc6\xd3\x05k\xd7'
        b"=\x05`\xae\xb4\xe4H\xf3\x1b,i\xbd\xce\xd7\x8c\xa9\xbee\x13e'\t\x01k\xa0\xf4]\xde\x00\xb1`\xe0\xba\xe9Qy/=\xed\xa1\xa2u\x08W[?\xabh@U\x83n\x04T\x81\x9c\x96\x939\x9f\x88\x87\r|"
        b'\xca\xd9g\xa8B\xad \x11\xd6\xbd\xa67\xa8+\xfd\xe6(\xd3\x81\xfay=\xc4W\xf9\x9fJ\x87\xb7\x82Q\xe9\xc2\xd1\xcb\xa6\xe2\x11\xc9jO\xb7R\x87\x02\x98\xddW\xbf_c\xca\xa0\x90\x85\xc2\xa0\x99\x9c\xc3k\x8a\xfb#'
        b'\xfd\xf7\xa2N\xe8\x00=H}\xac\xd4HMz\xabZQ\xf2\x94\xc7\xf2\x95\xa5+\xe2B\xf9\x92\xef\xee\x87\x14T\xe0\x17\x80\x90\x11\xef\x1d\xfdP\xdd\xb3\xe4\xcae\x8c\xcb\xa8\x93\x07i\xe0\x87\xae\xb3\xee\xe7%\xec_\xa5k'
        b"\xbe\t\x9ae\xab_\xd7B'\xedr\xb8W&\xb1\x890\x111\x147u\xc1\xa5\xfaO\x98\x8d\xee\x1f\xb7Us%\xeb\xd9q\xa0\xafa=H\xe0\xd4\xe2\xbe\xdfW:\xb5\x85\xdc\xba\xdf\x8c\x80\xec\xf7\x13\xbaQ\xfc<\x8f"
        b'>\x02O\xa1`\x1do\xc1LX\x88}P\x0c9\xe2g\xc3\x85\xef\'\x10\xdd\x90l\xc4\xc5\x19\xaa\x88_"\xdf?M\x94GL\x07F\x85\x91\xcb\xee\xa1-\x949S=}\xe6\x03\x18\x99\xfb\xc7\x99<\xa2 =\x82q'
        b"\xda\xbc\x8f\xbc\xf9\xbe\xb4\x8d\xff\xbe\xb7\xa2*ox\x9d\xad\xfc\x0c\xe7!X\x91\xdd\xbc'\xb8z\x19\xe8f\xe4h\xa8\xfe\xb3Q\xc2j\xea\xa5\x1e\xd8\x83\x9ei65 \x94\x9cT\xe8\x93\xbf\xc4\x7f \x8c?\x06'\x91,"
        b'\x8e\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r'
        b'\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
